<template>
  <div class="mobile-container">
    <van-sticky>
      <van-nav-bar
        :title="routerQuery.title || '安全排查方案'"
        left-arrow
        @click-left="_ => $router.go(-1)"
        @click-right="showPopup('querySearchPopup')"
      >
        <template #right>
          <van-icon name="search" size="18" />
        </template>
      </van-nav-bar>
    </van-sticky>
    <div class="content">
      <van-pull-refresh
        v-model="refreshing"
        @refresh="onRefresh"
        class="van-hairline--top"
        ref="refresh"
      >
        <van-list
          v-model="loading"
          :finished="finished"
          finished-text="没有更多了"
          @load="onLoad"
          :immediate-check="false"
        >
          <div
            v-for="(item, index) in listData"
            :key="index"
            class="device van-hairline--bottom"
            :class="{myStyle: index === listData.length - 1}"
          >
            <div class="device-item">
              <div class="device-item-top">
                <div class="device-item-top-left">
                  <van-tag
                    size="medium"
                    type="primary"
                    plain
                  >
                    {{ dictionaryEscape(checkTypeOpt, item.checkType) }}
                  </van-tag>
                </div>
              </div>
              <div class="device-item-content">
                <p>
                  <span class="label">排查月度：</span>
                  <span class="value">{{ item.checkYearMonth || '-' }}</span>
                </p>
                <p>
                  <span class="label">排查方案名称：</span>
                  <span class="value">{{ item.schemeName || '-' }}</span>
                </p>
                <p>
                  <span class="label">方案状态：</span>
                  <span class="value">
                    {{ dictionaryEscape(pubStateOpt, item.pubState, {congruent: false}) }}
                  </span>
                </p>
                <p>
                  <span class="label">排查计划：</span>
                  <span class="value">
                    {{ dictionaryEscape(checkPlanOpt, item.checkplanId) }}
                  </span>
                </p>
                <p>
                  <span class="label">开始时间：</span>
                  <span class="value">{{ item.startDate || '-' }}</span>
                </p>
                <p>
                  <span class="label">结束时间：</span>
                  <span class="value">{{ item.endDate || '-' }}</span>
                </p>
              </div>
              <div class="device-item-bottom">
                <van-button type="primary" size="mini" @click="showPopup('detailsPopup',item)">
                  详情
                </van-button>
              </div>
            </div>
          </div>
        </van-list>
      </van-pull-refresh>

      <!-- 列表筛选弹层 -->
      <QuerySearchPopup
        :isShow.sync="querySearchPopup"
        :checkTypeOpt="checkTypeOpt"
        :pubStateOpt="pubStateOpt"
        :customQueryPrams="customQueryPrams"
        @searchData="searchData"
      />

      <!--   详情弹层页面   -->
      <DetailsPopup
        :isShow.sync="detailsPopup"
        :checkTypeOpt="checkTypeOpt"
        :pubStateOpt="pubStateOpt"
        :checkPlanOpt="checkPlanOpt"
        :typeOpt="typeOpt"
        :checkCompanyOpt="checkCompanyOpt"
        :rowInfo="rowInfo"
      />
    </div>
  </div>
</template>

<script>
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'
import DetailsPopup from './components/DetailsPopup/index.vue'
import {dictionaryEscape} from '@/utils/dictionary'
import programApi from '@/views/Manage/saftyDanger/api/programApi'
import dictContracts from '@/components/dict/DictSelectUtils'
import CmgtSaftyDangerCheckplanApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckplanApi'
import nineLittlePlaceApi from '@/views/Manage/saftyDanger/api/nineLittlePlaceApi'

export default {
  name: 'SecurityInvestigationPlans',
  components: {DetailsPopup, QuerySearchPopup},
  data() {
    return {
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        check_type_: '',
        pub_state_: ''
      },
      sorter: [
        {
          'direction': 'DESC',
          'property': 'checkYearMonth'
        }
      ],
      listData: [],// 列表数据
      checkTypeOpt: dictContracts.getDictItemsFromCache('pclb') || [], // 排查方式配置数组
      pubStateOpt: dictContracts.getDictItemsFromCache('fazt') || [], // 发布状态配置数组
      typeOpt: dictContracts.getDictItemsFromCache('zhgl-dwlx'), // 单位类别配置数组
      checkCompanyOpt: [], // 排查单位配置数组
      checkPlanOpt: [], // 排查计划配置数组
      loading: false, // 列表是否触发loading
      finished: false, // 列表是否加载完成
      refreshing: false, // 列表是否开始下拉刷新
      querySearchPopup: false, // 搜索弹层
      detailsPopup: false, // 详情弹层
      rowInfo: {} // 单机行信息
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = this.customQueryPrams
      /*
      * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑(应对于Vant2下拉框无转义功能)
      *  为重新加工结构赋值的新请求配置参数
      * */
      const querys = [
        {property: 'check_type_', operation: 'EQUAL'},
        {property: 'pub_state_', operation: 'EQUAL'}
      ]
      const escapeOpt = {
        check_type_: 'checkTypeOpt',
        pub_state_: 'pubStateOpt'
      }
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          // 获取value值优先级：customQueryPrams.value > querys[i].value
          let value = item[i.property] || i.value || ''
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          let escape = this[escapeOpt[i.property]]  // 找寻翻译配置项
          if (escape) value = this.dictionaryEscape(escape, value, {dictionaryType: false})
          return {operation: 'LIKE', group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    },
    routerQuery() {
      return this.$route.query
    }
  },
  created() {
    this.getUnit()
    this.getcheckplanData()
    this.getListData()
  },
  methods: {
    // 字典转义(转义、翻译)
    dictionaryEscape,

    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData(_ => this.loading = false)
    },

    // 下拉时触发
    onRefresh() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData(_ => this.refreshing = false)
    },

    // 打开弹层
    showPopup(popupName, rowInfo) {
      this.rowInfo = rowInfo
      this[popupName] = true
    },

    // 获取列表数据
    async getListData(callback) {
      programApi.loadCmgtSaftyDangerUnit(this.queryParams, res => {
        const {rows, total} = res
        const {pageSize, page} = this.customQueryPrams
        this.listData = this.listData.concat(rows)
        this.$nextTick(_ => callback && callback())
        if (pageSize * page >= total) this.finished = true
      })
    },

    // 获得排查计划配置数组
    getcheckplanData() {
      CmgtSaftyDangerCheckplanApi.loadCmgtSaftyDangerCheckplan(
        {
          pageBean: {
            pageSize: -1,
            page: 1
          }
        },
        res => {
          this.checkPlanOpt = res.rows.map(({checkName = '', id = ''}) => ({
            name: checkName,
            value: id
          }))
        }
      )
    },

    // 获取排查单位配置数组
    getUnit() {
      nineLittlePlaceApi.loadCmgtSaftyDangerUnit(
        {
          pageBean: {
            pageSize: -1,
            page: 1
          }
        }).then(
        res => {
          this.checkCompanyOpt = res.data.rows.map(({unitName = '', id = ''}) => ({
            name: unitName,
            value: id
          }))
        }
      )
    },

    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    }
  }
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.mobile-container {
  width: 100%;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;

  .content {
    flex: 1;
    height: 0;
    background: #fff;

    .van-hairline--top {
      height: 100%;
      overflow: auto;

      .device {
        background-color: #f9f9f9;
        padding: 40px 40px 20px 40px;
        box-sizing: border-box;
        color: $--mobile-text-sub;
        width: 100%;

        .device-item {
          display: flex;
          flex-direction: column;
          column-gap: 100px;
          background-color: #fff;
          border-radius: 40px;
          padding: 80px 80px 60px 60px;
          box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);

          .device-item-top {
            display: flex;
            width: 100%;
            justify-content: space-between;
            align-items: center;


            .device-item-top-left {
              display: flex;
              align-items: center;
              column-gap: 40px;

              .van-tag {
                min-width: 35PX;
                display: flex;
                justify-content: center;
                font-weight: 600;
              }

              .code {
                font-weight: bold;
                color: #555;
              }
            }
          }

          .device-item-content {
            display: flex;
            flex-direction: column;
            row-gap: 30px;
            flex: 1;
            margin: 50px 0 30px;

            p {
              margin: 0;
              display: flex;

              .label {
                color: #333;
                font-size: 60px;
                flex: 2.5;
              }

              .value {
                font-size: 60px;
                flex: 7.5;
                word-break: break-all;
                overflow: hidden;
                display: -webkit-box;
                -webkit-line-clamp: 3;
                -webkit-box-orient: vertical;
              }
            }
          }

          .device-item-bottom {
            display: flex;
            justify-content: flex-end;

            ::v-deep .van-button {
              width: 60PX;
            }
          }
        }
      }

    }

    ::v-deep .van-search__label {
      font-size: 12PX;
    }

  }
}

</style>

<style lang="scss">
html {
  touch-action: pan-y;
}
</style>
